@@ -8,17 +8,17 @@ changelog
 ---------------
 List out projects stories that are delivered or finished (not accepted)
 
-show_stories
+show stories
 ---------------
 Lists all stories for a given project (will prompt you if not specified)
 Can filter by user with the `for` option
 By default show the top 20 stories, can specify more (or less) with the _number_ option
 
-show_story
+show story
 ---------------
 Show the details for a given story.  passing the project-index parameter will make it faster
 
-browser_open
+open
 ---------------
 Will open the given story in a browser.  passing the project-index parameter will make it faster
 
@@ -36,15 +36,14 @@ Create a story
 
 
 Usage:
-  pivotal_tools changelog [--project-index=<pi>]
-  pivotal_tools show_stories [--project-index=<pi>] [--for=<user_name>] [--number=<number_of_stories>]
-  pivotal_tools show_story <story_id> [--project-index=<pi>]
-  pivotal_tools browser_open <story_id> [--project-index=<pi>]
-  pivotal_tools scrum [--project-index=<pi>]
-  pivotal_tools poker [--project-index=<pi>]
-  pivotal_tools planning [--project-index=<pi>]
   pivotal_tools create (feature|bug|chore) <title> [<description>] [--project-index=<pi>]
   pivotal_tools (start|finish|deliver|accept|reject) story <story_id> [--project-index=<pi>]
+  pivotal_tools show stories [--project-index=<pi>] [--for=<user_name>] [--number=<number_of_stories>]
+  pivotal_tools show story <story_id> [--project-index=<pi>]
+  pivotal_tools open <story_id> [--project-index=<pi>]
+  pivotal_tools changelog [--project-index=<pi>]
+  pivotal_tools scrum [--project-index=<pi>]
+  pivotal_tools (planning|poker) [--project-index=<pi>]
 
 Options:
   -h --help             Show this screen.
@@ -188,6 +187,13 @@ def show_story(story_id, arguments):
         for note in story.notes:
             print "[{}] {}".format(initials(note.author), note.text)
 
+
+    if len(story.tasks) > 0:
+        print
+        print bold("Tasks:")
+        for task in story.tasks:
+            print "[{}] {}".format(x_or_space(task.complete), task.description)
+
     if len(story.attachments) > 0:
         print
         print bold("Attachments:")
@@ -218,6 +224,15 @@ def scrum(project):
 
         print
 
+    print bold("Bugs")
+    bugs = project.open_bugs()
+    if len(bugs) == 0:
+        print 'Not sure that I believe it, but there are no bugs'
+    for bug in bugs:
+        print "   #{:12s} {:4s} {}".format(bug.story_id,
+                                     initials(bug.owned_by),
+                                     bug.name)
+
 
 def poker(project):
     """CLI driven tool to help facilitate the periodic poker planning session
@@ -225,7 +240,6 @@ def poker(project):
     Will loop through and display unestimated stories, and prompt the team for an estimate.
     You can also open the current story in a browser for additional editing
     """
-
     total_stories = len(project.unestimated_stories())
     for idx, story in enumerate(project.unestimated_stories()):
         clear()
@@ -439,6 +453,13 @@ def pretty_print_story(story):
                 print "Description: {}".format(attachment.description)
             print "Url: {}".format(colored(attachment.url, 'blue'))
 
+
+    if len(story.tasks) > 0:
+        print
+        print bold("Tasks:")
+        for task in story.tasks:
+            print "[{}] {}".format(x_or_space(task.complete), task.description)
+
     if len(story.labels) > 0:
         print
         print "{} {}".format(bold('Labels:'), story.labels)
@@ -470,8 +491,14 @@ def _get_column_dimensions():
     return int(rows), int(cols)
 
 
+def x_or_space(complete):
+    if complete:
+        return 'X'
+    else:
+        return ' '
+
+
 def main():
-    clear()
 
     arguments = docopt(__doc__)
 
@@ -480,12 +507,12 @@ def main():
     if arguments['changelog']:
         project = prompt_project(arguments)
         generate_changelog(project)
-    elif arguments['show_stories']:
+    elif arguments['show'] and arguments['stories']:
         project = prompt_project(arguments)
         show_stories(project, arguments)
-    elif arguments['show_story']:
+    elif arguments['show'] and arguments['story']:
         show_story(arguments['<story_id>'], arguments)
-    elif arguments['browser_open']:
+    elif arguments['open']:
         browser_open(arguments['<story_id>'], arguments)
     elif arguments['scrum']:
         project = prompt_project(arguments)
