@@ -37,6 +37,14 @@ class Note(object):
         self.author = author
 
 
+class Task(object):
+    """object representation of a Pivotal Task, should be accessed from story.tasks"""
+    def __init__(self, task_id, description, complete):
+        self.task_id = task_id
+        self.description = description
+        self.complete = complete
+
+
 class Attachment(object):
     """object representation of a Pivotal attachment, should be accessed from story.attachments"""
     def __init__(self, attachment_id, description, url):
@@ -60,6 +68,7 @@ class Story(object):
         self.labels = None
         self.notes = []
         self.attachments = []
+        self.tasks = []
 
 
     @property
@@ -116,6 +125,14 @@ class Story(object):
                 url = _parse_text(attachment_node, 'url')
                 story.attachments.append(Attachment(attachment_id,description,url))
 
+        task_nodes = node.find('tasks')
+        if task_nodes is not None:
+            for task_node in task_nodes:
+                task_id = _parse_text(task_node, 'id')
+                description = _parse_text(task_node, 'description')
+                complete = _parse_boolean(task_node, 'complete')
+                story.tasks.append(Task(task_id, description, complete))
+
 
 
         return story
@@ -124,7 +141,6 @@ class Story(object):
         """changes the estimate of a story"""
         update_story_url ="https://www.pivotaltracker.com/services/v3/projects/{}/stories/{}?story[estimate]={}".format(self.project_id, self.story_id, estimate)
         response = _perform_pivotal_put(update_story_url)
-        print response.text
 
     def set_state(self, state):
         """changes the estimate of a story"""
@@ -176,7 +192,7 @@ class Project(object):
         """returns all projects for the given user"""
         projects_url = 'https://www.pivotaltracker.com/services/v3/projects'
         response = _perform_pivotal_get(projects_url)
-        #print response.text
+
         root = ET.fromstring(response.text)
         if root is not None:
             return [Project.from_node(project_node) for project_node in root]
@@ -209,6 +225,7 @@ class Project(object):
         story_url = "https://www.pivotaltracker.com/services/v3/projects/{}/stories/{}".format(self.project_id, story_id)
 
         resposne = _perform_pivotal_get(story_url)
+        # print resposne.text
         if resposne.status_code == 404:
             # Not Found
             return None
@@ -224,7 +241,10 @@ class Project(object):
 
     def unestimated_stories(self):
         stories = self.get_stories('type:feature state:unstarted')
-        return [story for story in stories if int(story.estimate) == -1]
+        return self.open_bugs() + [story for story in stories if int(story.estimate) == -1]
+
+    def open_bugs(self):
+        return self.get_stories('type:bug state:unstarted')
 
     def in_progress_stories(self):
         return self.get_stories('state:started,rejected')
@@ -239,6 +259,8 @@ class Project(object):
         return self.get_stories('state:unscheduled,unstarted,started,rejected type:bug')
 
 
+# TODO Handle requests.exceptions.ConnectionError
+
 def _perform_pivotal_get(url):
     headers = {'X-TrackerToken': TOKEN}
     # print url
@@ -247,21 +269,15 @@ def _perform_pivotal_get(url):
 
 
 def _perform_pivotal_put(url):
-    print "trying [{}]".format(url)
     headers = {'X-TrackerToken': TOKEN, 'Content-Length': 0}
     response = requests.put(url, headers=headers)
     response.raise_for_status()
     return response
 
 def _perform_pivotal_post(url,payload_xml):
-    print url
-    print payload_xml
     headers = {'X-TrackerToken': TOKEN, 'Content-type': "application/xml"}
     response = requests.post(url, data=payload_xml, headers=headers)
     response.raise_for_status()
-    print response.headers
-    print response.text
-    print response.status_code
     return response
 
 
@@ -292,5 +308,16 @@ def _parse_array(node, key):
     element = node.find(key)
     if element is not None:
         return element.text.split(',')
+    else:
+        return None
+
+def _parse_boolean(node, key):
+    """parses an boolean from an ElementTree node, if not found returns None"""
+    element = node.find(key)
+    if element is not None:
+        if element.text == 'true':
+            return True
+        else:
+            return False
     else:
         return None
\ No newline at end of file
